from setuptools import setup

setup(
    name='okdoodle',
    version = '0.0.3',
    description = 'say hello!',
    py_modlues = ["okdoodle"],
    package_dir = {'': 'src'},
    classifiers = [
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
    ],
    url = "https://github.com/Alan-Cyriac/okdoodle",
    author = ["Alan Cyriac", "Abhijith M"],
    author_email = "hr.doodleai@gmail.com",
)